@@ -34,6 +34,7 @@ class KITINERARY_EXPORT Action
 {
     KITINERARY_BASE_GADGET(Action)
     KITINERARY_PROPERTY(QUrl, target, setTarget)
+    KITINERARY_PROPERTY(QVariant, result, setResult)
 protected:
     ///@cond internal
     QExplicitlySharedDataPointer<ActionPrivate> d;
@@ -64,6 +65,14 @@ class KITINERARY_EXPORT DownloadAction : public Action
     KITINERARY_GADGET(DownloadAction)
 };
 
+/** Reserve action.
+ *  @see https://schema.org/ReserveAction
+ */
+class KITINERARY_EXPORT ReserveAction : public Action
+{
+    KITINERARY_GADGET(ReserveAction)
+};
+
 /** Edit/update action.
  *  @see https://schema.org/UpdateAction
  */
