@@ -20,6 +20,7 @@
 #include "config-kitinerary.h"
 #include "extractorpostprocessor.h"
 #include "extractorpostprocessor_p.h"
+#include "extractorvalidator_p.h"
 #include "flightpostprocessor_p.h"
 
 #include "extractorutil.h"
@@ -73,6 +74,7 @@ void ExtractorPostprocessor::process(const QVector<QVariant> &data)
     d->m_resultFinalized = false;
     d->m_data.reserve(d->m_data.size() + data.size());
     for (auto elem : data) {
+        // reservation types
         if (JsonLd::isA<FlightReservation>(elem)) {
             elem = d->processFlightReservation(elem.value<FlightReservation>());
         } else if (JsonLd::isA<TrainReservation>(elem)) {
@@ -93,6 +95,15 @@ void ExtractorPostprocessor::process(const QVector<QVariant> &data)
             elem = d->processTaxiReservation(elem.value<TaxiReservation>());
         }
 
+        // "reservationFor" types
+        else if (JsonLd::isA<LodgingBusiness>(elem)) {
+            elem = d->processPlace(elem.value<LodgingBusiness>());
+        } else if (JsonLd::isA<FoodEstablishment>(elem)) {
+            elem = d->processPlace(elem.value<FoodEstablishment>());
+        } else if (JsonLd::isA<Event>(elem)) {
+            elem = d->processEvent(elem.value<Event>());
+        }
+
         d->mergeOrAppend(elem);
     }
 }
@@ -101,7 +112,7 @@ QVector<QVariant> ExtractorPostprocessor::result() const
 {
     if (!d->m_resultFinalized) {
         for (auto it = d->m_data.begin(); it != d->m_data.end();) {
-            if (d->filterReservation(*it)) {
+            if (ExtractorValidator::isValidElement(*it)) {
                 ++it;
             } else {
                 //qCDebug(Log).noquote() << "Discarding element:" << QJsonDocument(JsonLdDocument::toJson({*it})).toJson();
@@ -141,6 +152,8 @@ QVariant ExtractorPostprocessorPrivate::processFlightReservation(FlightReservati
         const auto bcbpData = IataBcbpParser::parse(bcbp, m_contextDate.date());
         if (bcbpData.size() == 1) {
             res = JsonLdDocument::apply(bcbpData.at(0), res).value<FlightReservation>();
+            // standardize on the BCBP booking reference, not some secondary one we might have in structured data for example
+            res.setReservationNumber(bcbpData.at(0).value<FlightReservation>().reservationNumber());
         } else {
             for (const auto &data : bcbpData) {
                 if (MergeUtil::isSame(res, data)) {
@@ -190,26 +203,34 @@ static void applyStationData(const KnowledgeDb::TrainStation &record, TrainStati
     }
 }
 
+static void applyStationCountry(const QString &isoCode, TrainStation &station)
+{
+    auto addr = station.address();
+    if (addr.addressCountry().isEmpty()) {
+        addr.setAddressCountry(isoCode.toUpper());
+        station.setAddress(addr);
+    }
+}
+
 TrainStation ExtractorPostprocessorPrivate::processTrainStation(TrainStation station) const
 {
     const auto id = station.identifier();
     if (id.isEmpty()) { // empty -> null cleanup, to have more compact json-ld output
         station.setIdentifier(QString());
     } else if (id.startsWith(QLatin1String("sncf:")) && id.size() == 10) {
-        // Gare & Connexion ids start with a country code, propagate that to the station address field
-        auto addr = station.address();
-        if (addr.addressCountry().isEmpty()) {
-            addr.setAddressCountry(id.mid(5, 2).toUpper());
-            station.setAddress(addr);
-        }
         const auto record = KnowledgeDb::stationForGaresConnexionsId(KnowledgeDb::GaresConnexionsId{id.mid(5)});
         applyStationData(record, station);
+        applyStationCountry(id.mid(5, 2).toUpper(), station);
     } else if (id.startsWith(QLatin1String("ibnr:")) && id.size() == 12) {
         const auto record = KnowledgeDb::stationForIbnr(KnowledgeDb::IBNR{id.mid(5).toUInt()});
         applyStationData(record, station);
+        const auto country = KnowledgeDb::countryIdForUicCode(id.midRef(5, 2).toUShort()).toString();
+        applyStationCountry(country, station);
     } else if (id.startsWith(QLatin1String("uic:")) && id.size() == 11) {
         const auto record = KnowledgeDb::stationForUic(KnowledgeDb::UICStation{id.mid(4).toUInt()});
         applyStationData(record, station);
+        const auto country = KnowledgeDb::countryIdForUicCode(id.midRef(4, 2).toUShort()).toString();
+        applyStationCountry(country, station);
     }
 
     return processPlace(station);
@@ -265,6 +286,8 @@ BusTrip ExtractorPostprocessorPrivate::processBusTrip(BusTrip trip) const
     trip.setArrivalBusStop(processPlace(trip.arrivalBusStop()));
     trip.setDepartureTime(processTimeForLocation(trip.departureTime(), trip.departureBusStop()));
     trip.setArrivalTime(processTimeForLocation(trip.arrivalTime(), trip.arrivalBusStop()));
+    trip.setBusNumber(trip.busNumber().simplified());
+    trip.setBusName(trip.busName().simplified());
     return trip;
 }
 
@@ -355,12 +378,15 @@ Person ExtractorPostprocessorPrivate::processPerson(Person person) const
 {
     person.setName(person.name().simplified());
 
-    if (person.name().isEmpty() && !person.familyName().isEmpty() && !person.givenName().isEmpty()) {
+    // fill name with name parts, if it's empty
+    if ((person.name().isEmpty() || person.name() == person.familyName() || person.name() == person.givenName())
+        && !person.familyName().isEmpty() && !person.givenName().isEmpty())
+    {
         person.setName(person.givenName() + QLatin1Char(' ') + person.familyName());
     }
 
     // strip prefixes, they break comparisons
-    static const char* honorificPrefixes[] = { "MR ", "MS ", "MRS " };
+    static const char* const honorificPrefixes[] = { "MR ", "MS ", "MRS " };
     for (auto prefix : honorificPrefixes) {
         if (person.name().startsWith(QLatin1String(prefix), Qt::CaseInsensitive)) {
             person.setName(person.name().mid(strlen(prefix)));
@@ -378,6 +404,13 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
         const auto isoCode = KContacts::Address::countryToISO(addr.addressCountry()).toUpper();
         if (!isoCode.isEmpty()) {
             addr.setAddressCountry(isoCode);
+
+        // try ISO 3166-1 alpha-3, we get that e.g. from Flixbus
+        } else if (addr.addressCountry().size() == 3) {
+            const auto c = KnowledgeDb::countryIdFromIso3166_1alpha3(KnowledgeDb::CountryId3(addr.addressCountry()));
+            if (c.isValid()) {
+                addr.setAddressCountry(c.toString());
+            }
         }
     }
 
@@ -507,86 +540,3 @@ QDateTime ExtractorPostprocessorPrivate::processTimeForLocation(QDateTime dt, co
     }
     return dt;
 }
-
-
-bool ExtractorPostprocessorPrivate::filterReservation(const QVariant &res) const
-{
-    if (JsonLd::isA<FlightReservation>(res)) {
-        return filterFlight(res.value<FlightReservation>().reservationFor().value<Flight>());
-    }
-    if (JsonLd::isA<TrainReservation>(res)) {
-        return filterTrainTrip(res.value<TrainReservation>().reservationFor().value<TrainTrip>());
-    }
-    if (JsonLd::isA<BusReservation>(res)) {
-        return filterBusTrip(res.value<BusReservation>().reservationFor().value<BusTrip>());
-    }
-    if (JsonLd::isA<LodgingReservation>(res)) {
-        return filterLodgingReservation(res.value<LodgingReservation>());
-    }
-    if (JsonLd::isA<EventReservation>(res)) {
-        return filterEventReservation(res.value<EventReservation>());
-    }
-    if (JsonLd::isA<FoodEstablishmentReservation>(res)) {
-        return filterFoodReservation(res.value<FoodEstablishmentReservation>());
-    }
-
-    // types without specific filters yet
-    if (JsonLd::isA<TouristAttractionVisit>(res) ||
-            JsonLd::isA<RentalCarReservation>(res) ||
-            JsonLd::isA<TaxiReservation>(res)) {
-        return true;
-    }
-
-    // unknown top-level type
-    return false;
-}
-
-bool ExtractorPostprocessorPrivate::filterLodgingReservation(const LodgingReservation &res) const
-{
-    return res.checkinTime().isValid() && res.checkoutTime().isValid();
-}
-
-bool ExtractorPostprocessorPrivate::filterFlight(const Flight &flight) const
-{
-    // this will be valid if either boarding time, departure time or departure day is set
-    const auto validDate = flight.departureDay().isValid();
-    return filterAirport(flight.departureAirport())
-           && filterAirport(flight.arrivalAirport())
-           && validDate;
-}
-
-bool ExtractorPostprocessorPrivate::filterAirport(const Airport &airport) const
-{
-    return !airport.iataCode().isEmpty() || !airport.name().isEmpty();
-}
-
-bool ExtractorPostprocessorPrivate::filterTrainTrip(const TrainTrip &trip) const
-{
-    return filterTrainOrBusStation(trip.departureStation())
-           && filterTrainOrBusStation(trip.arrivalStation())
-           && trip.departureDay().isValid();
-}
-
-bool ExtractorPostprocessorPrivate::filterBusTrip(const BusTrip &trip) const
-{
-    return filterTrainOrBusStation(trip.departureBusStop())
-           && filterTrainOrBusStation(trip.arrivalBusStop())
-           && trip.departureTime().isValid() && trip.arrivalTime().isValid();
-}
-
-template <typename T>
-bool ExtractorPostprocessorPrivate::filterTrainOrBusStation(const T &station) const
-{
-    return !station.name().isEmpty();
-}
-
-bool ExtractorPostprocessorPrivate::filterEventReservation(const EventReservation &res) const
-{
-    const auto event = res.reservationFor().value<Event>();
-    return !event.name().isEmpty() && event.startDate().isValid();
-}
-
-bool ExtractorPostprocessorPrivate::filterFoodReservation(const FoodEstablishmentReservation &res) const
-{
-    return res.startTime().isValid();
-}
