@@ -22,7 +22,6 @@
 
 class GfxPath;
 class GfxState;
-class GlobalParams;
 
 class QBrush;
 class QPainterPath;
@@ -43,8 +42,6 @@ namespace PopplerUtils
 
     /** Convets a Poppler path into a Qt path. */
     QPainterPath convertPath(GfxPath *path, Qt::FillRule fillRule);
-
-    GlobalParams* globalParams();
 }
 
 }
